==> Perl-Lexer-0.14.tar.gz: Perl-Lexer-0.14/lib/Perl/gen/token_info_map.h <==
#if PERL_VERSION == 10 && PERL_SUBVERSION == 0
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 10 && PERL_SUBVERSION == 1
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 0
#include "token_info-5.11.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 1
#include "token_info-5.11.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 2
#include "token_info-5.11.2.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 3
#include "token_info-5.11.2.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 4
#include "token_info-5.11.4.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 5
#include "token_info-5.11.5.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 0
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 1
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 2
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 3
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 4
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 5
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 0
#include "token_info-5.13.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 1
#include "token_info-5.13.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 2
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 3
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 4
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 5
#include "token_info-5.13.5.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 6
#include "token_info-5.13.6.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 7
#include "token_info-5.13.7.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 8
#include "token_info-5.13.8.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 9
#include "token_info-5.13.8.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 10
#include "token_info-5.13.10.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 11
#include "token_info-5.13.10.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 0
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 1
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 2
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 3
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 4
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 0
#include "token_info-5.15.0.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 1
#include "token_info-5.15.1.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 2
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 3
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 4
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 5
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 6
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 7
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 8
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 9
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 0
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 1
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 2
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 3
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 0
#include "token_info-5.17.0.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 1
#include "token_info-5.17.1.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 2
#include "token_info-5.17.2.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 3
#include "token_info-5.17.3.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 4
#include "token_info-5.17.4.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 5
#include "token_info-5.17.5.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 6
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 7
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 8
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 9
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 10
#include "token_info-5.17.10.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 11
#include "token_info-5.17.10.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 0
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 1
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 2
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 3
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 4
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 0
#include "token_info-5.19.0.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 1
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 2
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 3
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 4
#include "token_info-5.19.4.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 5
#include "token_info-5.19.5.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 6
#include "token_info-5.19.5.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 7
#include "token_info-5.19.7.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 8
#include "token_info-5.19.8.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 9
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 10
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 11
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 0
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 1
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 2
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 0
#include "token_info-5.21.0.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 1
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 2
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 3
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 4
#include "token_info-5.21.4.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 5
#include "token_info-5.21.5.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 6
#include "token_info-5.21.6.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 7
#include "token_info-5.21.7.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 8
#include "token_info-5.21.8.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 9
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 10
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 11
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 22 && PERL_SUBVERSION == 0
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 0
#include "token_info-5.23.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 1
#include "token_info-5.23.0.h"
#elif PERL_VERSION > 23 || (PERL_VERSION == 23 && PERL_SUBVERSION > 1)
#include "token_info-latest.h"
#else
#error "No support for this perl version"
#endif

==> Perl-Lexer-0.15.tar.gz: Perl-Lexer-0.15/lib/Perl/gen/token_info_map.h <==
#if PERL_VERSION == 10 && PERL_SUBVERSION == 0
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 10 && PERL_SUBVERSION == 1
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 10
#include "token_info-5.10.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 0
#include "token_info-5.11.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 1
#include "token_info-5.11.0.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 2
#include "token_info-5.11.2.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 3
#include "token_info-5.11.2.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 4
#include "token_info-5.11.4.h"
#elif PERL_VERSION == 11 && PERL_SUBVERSION == 5
#include "token_info-5.11.5.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 0
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 1
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 2
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 3
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 4
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12 && PERL_SUBVERSION == 5
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 12
#include "token_info-5.12.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 0
#include "token_info-5.13.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 1
#include "token_info-5.13.0.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 2
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 3
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 4
#include "token_info-5.13.2.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 5
#include "token_info-5.13.5.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 6
#include "token_info-5.13.6.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 7
#include "token_info-5.13.7.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 8
#include "token_info-5.13.8.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 9
#include "token_info-5.13.8.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 10
#include "token_info-5.13.10.h"
#elif PERL_VERSION == 13 && PERL_SUBVERSION == 11
#include "token_info-5.13.10.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 0
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 1
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 2
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 3
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14 && PERL_SUBVERSION == 4
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 14
#include "token_info-5.14.0.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 0
#include "token_info-5.15.0.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 1
#include "token_info-5.15.1.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 2
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 3
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 4
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 5
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 6
#include "token_info-5.15.2.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 7
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 8
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 15 && PERL_SUBVERSION == 9
#include "token_info-5.15.7.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 0
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 1
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 2
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16 && PERL_SUBVERSION == 3
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 16
#include "token_info-5.16.0.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 0
#include "token_info-5.17.0.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 1
#include "token_info-5.17.1.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 2
#include "token_info-5.17.2.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 3
#include "token_info-5.17.3.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 4
#include "token_info-5.17.4.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 5
#include "token_info-5.17.5.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 6
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 7
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 8
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 9
#include "token_info-5.17.6.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 10
#include "token_info-5.17.10.h"
#elif PERL_VERSION == 17 && PERL_SUBVERSION == 11
#include "token_info-5.17.10.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 0
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 1
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 2
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 3
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18 && PERL_SUBVERSION == 4
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 18
#include "token_info-5.18.0.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 0
#include "token_info-5.19.0.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 1
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 2
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 3
#include "token_info-5.19.1.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 4
#include "token_info-5.19.4.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 5
#include "token_info-5.19.5.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 6
#include "token_info-5.19.5.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 7
#include "token_info-5.19.7.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 8
#include "token_info-5.19.8.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 9
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 10
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 19 && PERL_SUBVERSION == 11
#include "token_info-5.19.9.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 0
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 1
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 2
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20 && PERL_SUBVERSION == 3
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 20
#include "token_info-5.20.0.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 0
#include "token_info-5.21.0.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 1
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 2
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 3
#include "token_info-5.21.1.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 4
#include "token_info-5.21.4.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 5
#include "token_info-5.21.5.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 6
#include "token_info-5.21.6.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 7
#include "token_info-5.21.7.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 8
#include "token_info-5.21.8.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 9
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 10
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 21 && PERL_SUBVERSION == 11
#include "token_info-5.21.9.h"
#elif PERL_VERSION == 22 && PERL_SUBVERSION == 0
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 22
#include "token_info-5.22.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 0
#include "token_info-5.23.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 1
#include "token_info-5.23.0.h"
#elif PERL_VERSION == 23 && PERL_SUBVERSION == 2
#include "token_info-5.23.0.h"
#elif PERL_VERSION > 23 || (PERL_VERSION == 23 && PERL_SUBVERSION > 2)
#include "token_info-latest.h"
#else
#error "No support for this perl version"
#endif
